/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: RuleEB.java 4626 2009-07-30 14:08:48Z nicoulaj $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.rules.manager.ejb;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;

/**
 * The Visual Rule entity bean.
 *
 * @author HAN Tianyi
 *
 */
@Entity
@Table(name = "RULE")
public class RuleEB implements Serializable {
    /**
     * Version of serial.
     */
    private static final long serialVersionUID = 3603043818875621406L;

    /**
     * Primary key.
     */
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    @Column(name = "ruId", unique = false, nullable = false, insertable = false,
            updatable = false)
    private int ruId;

    /**
    * The rule name
    */
    private String name = "";

    /**
    * The LHS (conditions)
    */
    @OneToMany(mappedBy = "lhsRule", cascade = CascadeType.REMOVE, fetch = FetchType.LAZY)
    private List<LHSCodeSnippetEB> lhs = new ArrayList<LHSCodeSnippetEB>();

    /**
    * The RHS (actions)
    */
    @OneToMany(mappedBy = "rhsRule", cascade = CascadeType.REMOVE, fetch = FetchType.LAZY)
    private List<RHSCodeSnippetEB> rhs = new ArrayList<RHSCodeSnippetEB>();

    /**
     * The variables
     */
    private ArrayList<String> variables = new ArrayList<String>();
    
    /**
     * The entity bean of visual rule package
     */
    @ManyToOne(fetch = FetchType.EAGER)
    @JoinColumn(name = "ru_fk", nullable = true)
    private VisualRulePackageEB vrp;

    /**
     * Get the id
     *
     * @return id
     */
    public final int getRuId() {
        return ruId;
    }

    /**
     * Get the name
     *
     * @return name
     */
    public final String getName() {
        return name;
    }

    /**
     * Set the Name
     *
     * @param value
     *             the name for set
     */
    public final void setName(final String value) {
        this.name = value;
    }

    /**
     * Get the LHS Element
     *
     * @return lhs
     */
    public final List<LHSCodeSnippetEB> getLhs() {
        return lhs;
    }

    /**
     * Set the LHS Element
     *
     * @param value
     *             LHS Rule for set
     */
    public final void setLhs(final List<LHSCodeSnippetEB> value) {
        this.lhs = value;
    }

    /**
     * Get the RHS Element
     *
     * @return rhs
     */
    public final List<RHSCodeSnippetEB> getRhs() {
        return rhs;
    }

    /**
     * Set the RHS Rule
     *
     * @param value
     *             RHS Rule for setting
     */
    public final void setRhs(final List<RHSCodeSnippetEB> value) {
        this.rhs = value;
    }

    /**
     * Get the visual rule package
     *
     * @return vrp
     */
    public final VisualRulePackageEB getVrp() {
        return vrp;
    }

    /**
     * Set the visual rule package
     *
     * @param value
     *             the visual rule package for setting
     */
    public final void setVrp(final VisualRulePackageEB value) {
        this.vrp = value;
    }
    
	/**
	 * Set the variables
	 */
	public final void setVariables(ArrayList<String> value) {
		variables = value;
	}
	
	/**
	 * Get the variables
	 */
	public final ArrayList<String> getVariables() {
		return variables;
	}

}
