/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: RulePackageEB.java 4504 2009-07-23 14:16:21Z hant $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.rules.manager.ejb;

import java.io.Serializable;

import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToOne;
import javax.persistence.Table;

/**
 * The Rule entity bean.
 *
 * @author HAN Tianyi
 *
 */
@Entity
@Table(name = "RULE_PACKAGE")
public class RulePackageEB implements Serializable {
    /**
     * Version of serial.
     */
    private static final long serialVersionUID = 3603043818875621406L;

    /**
     * Primary key.
     */
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private int id;

    /**
     * The unique system name of the rule package. Identifies the object, must
     * be different for each rule package. Automatically generated from the rule
     * package "display" name.
     *
     * @example "org.ow2.jasmine.monitoring.rules.example.ExamplePackage"
     */
    private String systemName;

    /**
     * The displayed name of the rule package. This is the name that is choosed
     * by the user. Used to generate automatically the systemName property.
     *
     * @example "Example Package"
     */
    private String displayName;
    /**
     * The name of the rule engine instance on which the rule is executed.
     */
    private String ruleEngineInstanceName;

    /**
     * The state of the rule package. Values can be:
     */
    private String state;

    /**
     * The description of the rule package
     */
    private String description;

    /**
     * The entity bean of textual rule package
     */
    @OneToOne
    @JoinColumn(name = "trpId")
    private TextualRulePackageEB trp;

    /**
     * The entity bean of visual rule package
     */
    @OneToOne
    @JoinColumn(name = "vrpId")
    private VisualRulePackageEB vrp;

    /**
     * Default constructor.
     *
     */
    public RulePackageEB() {
    }

    // ------------------------------------------------------------------------
    // Getters & setters
    // ------------------------------------------------------------------------

    /**
     * Get the id
     *
     * @return id
     */
    public final int getId() {
        return id;
    }

    /**
     * Get the system name
     *
     * @return systemName
     */
    public final String getSystemName() {
        return systemName;
    }

    /**
     * Set the system name
     *
     * @param value
     *             the system name for setting
     */
    public final void setSystemName(final String value) {
        this.systemName = value;
    }

    /**
     * Get the display name
     *
     * @return displayName
     */
    public final String getDisplayName() {
        return displayName;
    }

    /**
     * Set the display name
     *
     * @param value
     *             the display name for setting
     */
    public final void setDisplayName(final String value) {
        this.displayName = value;
    }

    /**
     * Set the name of the rule engine instance on which the rule is executed.
     */
    public final void setRuleEngineInstanceName(final String value) {
    	ruleEngineInstanceName = value;
    }
    
    /**
     * Set the name of the rule engine instance on which the rule is executed.
     */
    public final String getRuleEngineInstanceName() {
    	return ruleEngineInstanceName;
    }

    /**
     * Get the state
     *
     * @return state
     */
    public final String getState() {
        return state;
    }

    /**
     * Set the state
     *
     * @param value
     *             the state for setting
     */
    public final void setState(final String value) {
        this.state = value;
    }

    /**
     * Get the description
     *
     * @return description
     */
    public final String getDescription() {
        return description;
    }

    /**
     * Set the description
     *
     * @param value
     *             the description for setting
     */
    public final void setDescription(final String value) {
        this.description = value;
    }

    /**
     * Get the textual rule package
     * 
     * @return textualRulePackage
     */
    public final TextualRulePackageEB getTrp() {
        return trp;
    }

    /**
     * Set the textual rule package
     *
     * @param value
     *             the textual rule package for setting
     */
    public final void setTrp(final TextualRulePackageEB value) {
        this.trp = value;
    }

    /**
     * Get the visual rule package
     *
     * @return visualRulePackage
     */
    public final VisualRulePackageEB getVrp() {
        return vrp;
    }

    /**
     * Set the visual rule package
     *
     * @param value
     *             the visual rule package for setting
     */
    public final void setVrp(final VisualRulePackageEB value) {
        this.vrp = value;
    }

}
