/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: VisualRulePackageEB.java 4626 2009-07-30 14:08:48Z nicoulaj $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.rules.manager.ejb;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.OneToMany;

/**
 * The Visual Rule entity bean.
 *
 * @author HAN Tianyi
 *
 */
@Entity
@Table(name = "VISUAL_RULE_PACKAGE")
public class VisualRulePackageEB implements Serializable {
    /**
     * Version of serial.
     */
    private static final long serialVersionUID = 3603043818875621406L;

    /**
     * Primary key.
     */
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private int vrpId;

    /**
     * The rules
     */
    @OneToMany(mappedBy = "vrp", cascade = CascadeType.REMOVE, fetch = FetchType.LAZY)
    private List<RuleEB> rules = new ArrayList<RuleEB>();

    /**
     * The imports
     */
    private ArrayList<String> imports = new ArrayList<String>();
    
    
    // ------------------------------------------------------------------------
    // Getters & setters
    // ------------------------------------------------------------------------

    /**
     * Get the id
     *
     * @return id
     */
    public final int getVrpId() {
        return vrpId;
    }

    /**
     * Get the list of rules
     *
     * @return id
     */
    public final List<RuleEB> getRules() {
        return rules;
    }

    /**
     * Set the Rules
     *
     * @param value
     *             List of rules for setting
     */
    public final void setRules(final List<RuleEB> value) {
        this.rules = value;
    }
    
	/**
	 * Set the imports
	 */
	public void setImports(ArrayList<String> value) {
		imports = value;
	}
	
	/**
	 * Get the imports
	 */
	public ArrayList<String> getImports() {
		return imports;
	}

}
